Menu

Struct Menu 

pub struct Menu { /* private fields */ }
A menu, which contains zero or more items

Implementations

Source

impl Menu

pub fn name(&self) -> String

Returns the name of this menu

pub fn set_name<S: AsRef<str>>(&self, name: S) -> Result<(), NulError>

Sets the name of this menu

Errors

Returns an error if the name contains a NUL byte

pub fn add_child<R, C>(&self, child: R)
where R: Into<Rc<C>>, Rc<C>: Into<Item>,

Adds a child to this menu The child argument may be a Menu, ActionItem, CheckItem, or Separator, or an Rc containing one of these types.

pub fn add_to_plugins_menu(&self) -> Result<(), MenuError>

Adds this menu as a child of the plugins menu

Errors

This function will error if this Menu is already in a menu.

pub fn remove_from_plugins_menu(&self) -> Result<(), MenuError>

Removes this menu from the plugins menu

Errors

This function will error if this Menu is not in the plugins menu, or if it is not in any menu at all.