WeatherApi

Struct WeatherApi 

pub struct WeatherApi { /* private fields */ }
Struct to access weather APIs.

Implementations

Source

impl WeatherApi

pub fn get_aerodrome_metar<S: Into<Vec<u8>>>(ad: S) -> Result<String, NulError>

Get the METAR for the given aerodrome.

Errors

Returns an error if the aerodrome ID contains a null byte, or if the METAR returned by X-Plane is not valid UTF-8. X-Plane should be giving UTF-8, per the developers.

Panics

Panics if X-Plane provides invalid UTF-8. This should be impossible.

pub fn get_weather_at_location( lat: f64, lon: f64, alt_m: f64, ) -> Option<XPLMWeatherInfo_t>

Get the weather at the given location. The location must be near the user. Weather may not be available at the location, in which case None will be returned.