pub struct FeatureApi { /* private fields */ }Expand description
Access struct for the Feature API.
Implementations
Sourceimpl FeatureApi
impl FeatureApi
Sourcepub fn find<S: Into<String>>(
&mut self,
name: S,
) -> Result<Option<Feature>, NulError>
pub fn find<S: Into<String>>( &mut self, name: S, ) -> Result<Option<Feature>, NulError>
Looks for a feature with the provided name and returns it if it exists
Errors
This function will return an error if name contains a NUL byte.
Panics
This function can panic if name, which came in as a String-like, then was turned into a CString,
cannot be turned back into a String. This should not be possible.